==> haskell-utility-ht-0.0.17.2-101.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-utility-ht.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 utility-ht
version:              0.0.17.2
visibility:           public
id:                   utility-ht-0.0.17.2-FCtUbDIssee2G1L1Lv2g90
key:                  utility-ht-0.0.17.2-FCtUbDIssee2G1L1Lv2g90
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
stability:            Stable
synopsis:
    Various small helper functions for Lists, Maybes, Tuples, Functions

description:
    Various small helper functions for Lists, Maybes, Tuples, Functions.
    Some of these functions are improved implementations of standard functions.
    They have the same name as their standard counterparts.
    Others are equivalent to functions from the @base@ package,
    but if you import them from this utility package
    then you can write code that runs on older GHC versions
    or other compilers like Hugs and JHC.

    All modules are plain Haskell 98.
    The package depends exclusively on the @base@ package
    and only that portions of @base@ that are simple to port.
    Thus you do not risk a dependency avalanche by importing it.
    However, further splitting the base package might invalidate this statement.

    Alternative packages: @Useful@, @MissingH@

category:             Data, List
abi:                  0efaa535b6a98922a635a0be0962ce41
exposed:              True
exposed-modules:
    Control.Applicative.HT Control.Functor.HT Control.Monad.HT
    Data.Bits.HT Data.Bool.HT Data.Either.HT Data.Eq.HT
    Data.Function.HT Data.Ix.Enum Data.List.HT Data.List.Key
    Data.List.Match Data.List.Reverse.StrictElement
    Data.List.Reverse.StrictSpine Data.Maybe.HT Data.Monoid.HT
    Data.Ord.HT Data.Record.HT Data.Strictness.HT Data.String.HT
    Data.Tuple.HT Data.Tuple.Lazy Data.Tuple.Strict Text.Read.HT
    Text.Show.HT

hidden-modules:
    Data.Bool.HT.Private Data.List.HT.Private Data.List.Key.Private
    Data.List.Match.Private Data.List.Reverse.Private
    Data.Function.HT.Private Data.Record.HT.Private Data.Tuple.Example

import-dirs:          /usr/lib/ghc-9.6.6/site-local/utility-ht-0.0.17.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/utility-ht-0.0.17.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/utility-ht-0.0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-utility-ht
hs-libraries:         HSutility-ht-0.0.17.2-FCtUbDIssee2G1L1Lv2g90
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-utility-ht/html/utility-ht.haddock
haddock-html:         /usr/share/doc/haskell-utility-ht/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-utility-ht-0.0.17.2-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-utility-ht.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 utility-ht
version:              0.0.17.2
visibility:           public
id:                   utility-ht-0.0.17.2-9ryTCp5DXpz5HmwvPaZxIP
key:                  utility-ht-0.0.17.2-9ryTCp5DXpz5HmwvPaZxIP
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
stability:            Stable
synopsis:
    Various small helper functions for Lists, Maybes, Tuples, Functions

description:
    Various small helper functions for Lists, Maybes, Tuples, Functions.
    Some of these functions are improved implementations of standard functions.
    They have the same name as their standard counterparts.
    Others are equivalent to functions from the @base@ package,
    but if you import them from this utility package
    then you can write code that runs on older GHC versions
    or other compilers like Hugs and JHC.

    All modules are plain Haskell 98.
    The package depends exclusively on the @base@ package
    and only that portions of @base@ that are simple to port.
    Thus you do not risk a dependency avalanche by importing it.
    However, further splitting the base package might invalidate this statement.

    Alternative packages: @Useful@, @MissingH@

category:             Data, List
abi:                  1fe5ff0b90cc216da174c7b452d51ea8
exposed:              True
exposed-modules:
    Control.Applicative.HT Control.Functor.HT Control.Monad.HT
    Data.Bits.HT Data.Bool.HT Data.Either.HT Data.Eq.HT
    Data.Function.HT Data.Ix.Enum Data.List.HT Data.List.Key
    Data.List.Match Data.List.Reverse.StrictElement
    Data.List.Reverse.StrictSpine Data.Maybe.HT Data.Monoid.HT
    Data.Ord.HT Data.Record.HT Data.Strictness.HT Data.String.HT
    Data.Tuple.HT Data.Tuple.Lazy Data.Tuple.Strict Text.Read.HT
    Text.Show.HT

hidden-modules:
    Data.Bool.HT.Private Data.List.HT.Private Data.List.Key.Private
    Data.List.Match.Private Data.List.Reverse.Private
    Data.Function.HT.Private Data.Record.HT.Private Data.Tuple.Example

import-dirs:          /usr/lib/ghc-9.6.6/site-local/utility-ht-0.0.17.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/utility-ht-0.0.17.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/utility-ht-0.0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-utility-ht
hs-libraries:         HSutility-ht-0.0.17.2-9ryTCp5DXpz5HmwvPaZxIP
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-utility-ht/html/utility-ht.haddock
haddock-html:         /usr/share/doc/haskell-utility-ht/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
